EC 2003 Barcelona, Spain October 19th 2003 80 players Stefan Ferenci "little brother is watching you" there are some minor flaws and this deck needs to be tweaked a little: this deck is currently 75 cards it should be tuned down to 60-65 cards or increase the number of blood dolls. play style be patient gain pool influence minions and stay in the background there has to be always a bigger threat on the table. try to burn vamps with the society play them when the vamp is on one or 2 blood. Crypt (12 cards, min=7, max=16, avg=2.92) ----------------------------------------- 1x Idalia, Prophet of Guadalajara 4 AUS dem Malkavian antitribu:2 1x Maldavis 4 AUS for pre Caitiff:3 1x Remilliard, Devout Crusader 4 AUS pre Toreador antitribu:2 1x Richard Tauber, Ayelea's Puppet 4 AUS tha Tremere antitribu:2 1x David Morgan, The Scourge 3 aus pot Malkavian:3 1x Isabel de Leon 3 AUS Toreador:2 1x Martin Franckel 3 AUS tha Tremere:3 1x Milo, The Invisible Horror 3 aus obf Malkavian:3 1x Zöe 3 AUS cel obf Malkavian:2 1x Almiro Suarez 2 aus Tremere:3 1x Feo Ramos 1 aus Pander:3 1x Franciscus 1 aus Caitiff:2 Library (75 cards) Master (21) 1x Academic Hunting Ground 1x Asylum Hunting Ground 2x Auspex -- don't need them, maybe one! 5x Blood Doll 2x Millicent Smith, Puritan Vampire Hunter 2x Pentex(TM) Subversion 1x Powerbase: Montreal 1x Rack, The 3x Smiling Jack, The Anarch -- to many! 3x Society of Leopold Ally (1) 1x Muddled Vampire Hunter Equipment (3) 1x Ivory Bow 1x Palatial Estate 1x Sengir Dagger Reaction (39) 5x Eagle's Sight 5x Enhanced Senses 9x Forced Awakening 5x My Enemy's Enemy 5x Precognition 5x Spirit's Touch 5x Telepathic Misdirection Combat (11) 1x Disguised Weapon 8x Dodge 2x Pulled Fangs